==================
User Documentation
==================

This part of the documentation provides detailed information about the
Mistral capabilities, use cases and also complete description of Mistral
Workflow Language and APIs. If you want to write Mistral workflows and
and run them with the Mistral service, it is highly recommended to read
the articles of this part one by one. Please pay a special attention to
the examples since they're proven to explain Mistral concepts best.
However, you can also read individual articles in case you are searching
info on concrete features.


.. toctree::
    :maxdepth: 2

    overview
    faq
    terminology/index
    main_features
    use_cases/index
    wf_namespaces
    asynchronous_actions
    wf_lang_v2
    rest_api_v2
    cli/index
    cookbooks/index
